package com.ruoyi.bst.ad.service.impl;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.ruoyi.bst.ad.enums.AdBlong;
import com.ruoyi.bst.ad.service.AdConverter;
import com.ruoyi.bst.area.domain.AreaVO;
import com.ruoyi.bst.area.service.AreaService;
import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.service.OrderService;
import com.ruoyi.common.core.domain.entity.User;
import com.ruoyi.common.core.domain.vo.UserVO;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.system.user.service.UserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.ad.mapper.AdMapper;
import com.ruoyi.bst.ad.domain.Ad;
import com.ruoyi.bst.ad.domain.AdVO;
import com.ruoyi.bst.ad.domain.AdQuery;
import com.ruoyi.bst.ad.service.AdService;

/**
 * 广告Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-01
 */
@Service
public class AdServiceImpl implements AdService
{
    @Autowired
    private AdMapper adMapper;
    @Autowired
    private AdConverter adConverter;
    @Autowired
    private OrderService orderService;
    @Autowired
    private AreaService areaService;
    @Autowired
    private UserService userService;

    /**
     * 查询广告
     *
     * @param adId 广告主键
     * @return 广告
     */
    @Override
    public AdVO selectAdByAdId(Long adId)
    {
        return adMapper.selectAdByAdId(adId);
    }

    /**
     * 查询广告列表
     *
     * @param ad 广告
     * @return 广告
     */
    @Override
    public List<AdVO> selectAdList(AdQuery ad)
    {
        return adMapper.selectAdList(ad);
    }

    /**
     * 新增广告
     *
     * @param ad 广告
     * @return 结果
     */
    @Override
    public int insertAd(Ad ad)
    {
        if (ad.getBelong() == null || ad.getBelong().equals("")){
            ad.setBelong(AdBlong.STORE.getCode());
        }
        AdQuery query = new AdQuery();
        query.setAreaId(ad.getAreaId());
        if (ad.getAreaId() != null){
            AreaVO area = areaService.selectAreaById(ad.getAreaId());
            ad.setStoreId(area.getUserId());
            ServiceUtil.assertion(adMapper.selectOne(query)!=null,"当前运营区存在广告已达上限");
        }
        ad.setCreateTime(DateUtils.getNowDate());
        return adMapper.insertAd(ad);
    }

    /**
     * 修改广告
     *
     * @param ad 广告
     * @return 结果
     */
    @Override
    public int updateAd(Ad ad)
    {
        if (ad.getAreaId() != null){
            AdVO oldAd = adMapper.selectAdByAdId(ad.getAdId());
            ServiceUtil.assertion(oldAd == null,"广告不存在");
            if (!oldAd.getAreaId().equals(ad.getAreaId())){
                int count = adMapper.countByAreaId(ad.getAreaId(),ad.getAdId());
                ServiceUtil.assertion(count>0,"该运营区下广告已达上限");
            }
        }
        AreaVO area = areaService.selectAreaById(ad.getAreaId());
        ad.setStoreId(area.getUserId());
        ad.setUpdateTime(DateUtils.getNowDate());
        return adMapper.updateAd(ad);
    }

    /**
     * 批量删除广告
     *
     * @param adIds 需要删除的广告主键
     * @return 结果
     */
    @Override
    public int deleteAdByAdIds(List<Long> adIds)
    {
        return adMapper.deleteAdByAdIds(adIds);
    }

    /**
     * 删除广告信息
     *
     * @param adId 广告主键
     * @return 结果
     */
    @Override
    public int deleteAdByAdId(Long adId)
    {
        return adMapper.deleteAdByAdId(adId);
    }

    @Override
    public AdVO selectOne(AdQuery query) {
        return adMapper.selectOne(query);
    }


    @Override
    public List<AdVO> toAppVOList() {
        List<AdVO> list = new ArrayList<>();
        OrderQuery orderQuery = new OrderQuery();
        orderQuery.setUserId(SecurityUtils.getUserId());
        OrderVO orderVO = orderService.selectOne(orderQuery);
        // 如果有订单,查询对应商户的广告
        if (orderVO != null) {
            AdQuery adStoreVO = adConverter.toAdStoreVO();
            adStoreVO.setStoreId(orderVO.getAreaUserId());
            AdVO vo = adMapper.selectOne(adStoreVO);
            if (vo != null) {
                list.add(vo);
            }
        }
        // 查询管理员发布的广告
        List<AdVO> adminVOList = adMapper.selectAdList(adConverter.toAdAdminVO());
        if (adminVOList != null) {
            list.addAll(adminVOList);
        }
        return list;
    }

    @Override
    public int logicalDel(List<Long> adIds) {
        return adMapper.logicalDel(adIds);
    }
}
